summaryrefslogtreecommitdiffstats
path: root/siputils.py
diff options
context:
space:
mode:
Diffstat (limited to 'siputils.py')
-rw-r--r--siputils.py36
1 files changed, 18 insertions, 18 deletions
diff --git a/siputils.py b/siputils.py
index ca3d92e..b5b1860 100644
--- a/siputils.py
+++ b/siputils.py
@@ -1,19 +1,19 @@
# This module is intended to be used by the build/installation scripts of
# extension modules created with SIP. It provides information about file
# locations, version numbers etc., and provides some classes and functions.
#
# Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
#
# This file is part of SIP.
#
-# This copy of SIP is licensed for use under the terms of the SIP License
+# This copy of SIP-TQt is licensed for use under the terms of the SIP License
# Agreement. See the file LICENSE for more details.
#
# This copy of SIP may also used under the terms of the GNU General Public
# License v2 or v3 as published by the Free Software Foundation which can be
# found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
#
# SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -24,7 +24,7 @@ import string
import re
# These are installation specific values created when SIP was configured.
# @SIP_CONFIGURATION@
# The stack of configuration dictionaries.
@@ -32,7 +32,7 @@ _config_stack = []
class Configuration(object):
"""The class that represents SIP configuration values.
"""
def __init__(self, sub_cfg=None):
"""Initialise an instance of the class.
@@ -412,7 +412,7 @@ class Makefile:
for l in self.extra_lib_dirs:
# Ignore relative directories. This is really a hack to handle
- # SIP v3 inter-module linking.
+ # SIP-TQt v3 inter-module linking.
if os.path.dirname(l) not in ("", ".", ".."):
rpaths.append(l)
@@ -1425,7 +1425,7 @@ class ModuleMakefile(Makefile):
dl = getattr(sys, 'real_prefix', sys.exec_prefix).split(os.sep)
if "Python.framework" not in dl:
- error("SIP requires Python to be built as a framework")
+ error("SIP-TQt requires Python to be built as a framework")
self.LFLAGS.append("-undefined dynamic_lookup")
@@ -1436,7 +1436,7 @@ class ModuleMakefile(Makefile):
# AIX needs a lot of special handling.
if self.required_string('LINK') == 'g++':
# g++ is used for linking.
- # For SIP v4 and g++:
+ # For SIP-TQt v4 and g++:
# 1.) Import the python symbols
aix_lflags = ['-Wl,-bI:%s/python.exp' % self.config.py_lib_dir]
@@ -1446,7 +1446,7 @@ class ModuleMakefile(Makefile):
aix_lflags.append('-Wl,-bE:%s.exp' % self._target)
else:
# IBM VisualAge C++ is used for linking.
# For SIP v4 and xlC:
# 1.) Create a shared object
# 2.) Import the python symbols
aix_lflags = ['-qmkshrobj',
@@ -1485,12 +1485,12 @@ class ModuleMakefile(Makefile):
self.LFLAGS.remove('-Wl,--no-undefined')
def module_as_lib(self, mname):
"""Return the name of a SIP v3.x module when it is used as a library.
This will raise an exception when used with SIP v4.x modules.
mname is the name of the module.
"""
- raise ValueError("module_as_lib() can only be used with SIP v3.x")
+ raise ValueError("module_as_lib() can only be used with SIP-TQt v3.x")
def generate_macros_and_rules(self, mfile):
"""Generate the macros and rules generation.
@@ -1643,13 +1643,13 @@ class ModuleMakefile(Makefile):
class SIPModuleMakefile(ModuleMakefile):
- """The class that represents a SIP generated module Makefile.
+ """The class that represents a SIP-TQt generated module Makefile.
"""
def __init__(self, configuration, build_file, install_dir=None, static=0,
console=0, qt=0, opengl=0, threaded=0, warnings=1, debug=0,
dir=None, makefile="Makefile", installs=None, strip=1,
export_all=0, universal=None, arch=None, prot_is_public=0):
- """Initialise an instance of a SIP generated module Makefile.
+ """Initialise an instance of a SIP-TQt generated module Makefile.
prot_is_public is set if "protected" is to be redefined as "public".
If the platform's C++ ABI allows it this can significantly reduce the
@@ -1664,7 +1664,7 @@ class SIPModuleMakefile(ModuleMakefile):
self._prot_is_public = prot_is_public
def finalise(self):
- """Finalise the macros for a SIP generated module Makefile.
+ """Finalise the macros for a SIP-TQt generated module Makefile.
"""
if self._prot_is_public:
self.DEFINES.append('SIP_PROTECTED_IS_PUBLIC')
@@ -2083,7 +2083,7 @@ def create_config_module(module, template, content, macros=None):
def version_to_sip_tag(version, tags, description):
"""Convert a version number to a SIP tag.
version is the version number. If it is negative then the latest version
is assumed. (This is typically useful if a snapshot is indicated by a
@@ -1,19 +1,19 @@
# This module is intended to be used by the build/installation scripts of
-# extension modules created with SIP. It provides information about file
+# extension modules created with SIP-TQt. It provides information about file
# locations, version numbers etc., and provides some classes and functions.
#
@@ -1,19 +1,19 @@
# Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
#
-# This file is part of SIP.
+# This file is part of SIP-TQt.
#
@@ -1,19 +1,19 @@
# Agreement. See the file LICENSE for more details.
#
-# This copy of SIP may also used under the terms of the GNU General Public
+# This copy of SIP-TQt may also used under the terms of the GNU General Public
# License v2 or v3 as published by the Free Software Foundation which can be
# found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
@@ -1,19 +1,19 @@
# found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
#
-# SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
+# SIP-TQt is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -24,7 +24,7 @@ import string
import re
-# These are installation specific values created when SIP was configured.
+# These are installation specific values created when SIP-TQt was configured.
# @SIP_CONFIGURATION@
# The stack of configuration dictionaries.
@@ -32,7 +32,7 @@ _config_stack = []
class Configuration(object):
- """The class that represents SIP configuration values.
+ """The class that represents SIP-TQt configuration values.
"""
def __init__(self, sub_cfg=None):
@@ -1446,7 +1446,7 @@ class ModuleMakefile(Makefile):
else:
# IBM VisualAge C++ is used for linking.
- # For SIP v4 and xlC:
+ # For SIP-TQt v4 and xlC:
# 1.) Create a shared object
# 2.) Import the python symbols
@@ -1485,12 +1485,12 @@ class ModuleMakefile(Makefile):
self.LFLAGS.remove('-Wl,--no-undefined')
def module_as_lib(self, mname):
- """Return the name of a SIP v3.x module when it is used as a library.
- This will raise an exception when used with SIP v4.x modules.
+ """Return the name of a SIP-TQt v3.x module when it is used as a library.
+ This will raise an exception when used with SIP-TQt v4.x modules.
mname is the name of the module.
"""
@@ -2083,7 +2083,7 @@ def create_config_module(module, template, content, macros=None):
def version_to_sip_tag(version, tags, description):
- """Convert a version number to a SIP tag.
+ """Convert a version number to a SIP-TQt tag.
version is the version number. If it is negative then the latest version
is assumed. (This is typically useful if a snapshot is indicated by a